@@ -1,21 +1,22 @@
 import re
 import random
-from typing import Tuple, List
-from nonebot import export, on_command, on_message, on_regex
-from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, Message, MessageEvent
+from typing import List, Tuple
+
+from nonebot import export, on_regex, on_command, on_message
+from nonebot.params import State, CommandArg, RegexGroup
+from nonebot.typing import T_State, T_Handler
+from nonebot.matcher import Matcher
+from nonebot.permission import SUPERUSER
+from nonebot.adapters.onebot.v11 import Bot, Message, MessageEvent, GroupMessageEvent
 from nonebot.adapters.onebot.v11.permission import (
     GROUP_ADMIN,
     GROUP_OWNER,
     PRIVATE_FRIEND,
 )
-from nonebot.matcher import Matcher
-from nonebot.params import CommandArg, RegexGroup, State
-from nonebot.permission import SUPERUSER
-from nonebot.typing import T_State, T_Handler
 
+from .util import parse_msg, save_and_convert_img
 from .models import MatchType
 from .data_source import word_bank as wb
-from .util import parse_msg, save_and_convert_img
 
 reply_type = "random"
 
@@ -212,3 +213,40 @@ async def _(matcher: Matcher, state: T_State = State()):
             await matcher.finish(Message.template("删除{keyword}词库成功~"))
     else:
         await matcher.finish("命令取消")
+
+
+wb_search_cmd = on_regex(
+    r"^查询\s*((?:模糊|正则|@)*)\s*词库\s*(.*?)\s*$",
+    flags=re.S,
+    block=True,
+    priority=10,
+    permission=PERM_EDIT,
+)
+
+wb_search_cmd_gl = on_regex(
+    r"^查询\s*((?:群|用户)*)\s*(\d*)\s*((?:全局|模糊|正则|@)*)\s*词库\s*(.*?)\s*$",
+    flags=re.S,
+    block=True,
+    priority=10,
+    permission=PERM_GLOBAL,
+)
+
+
+@wb_search_cmd_gl.handle()
+@wb_search_cmd.handle()
+async def wb_search(
+    bot: Bot,
+    event: MessageEvent,
+    matcher: Matcher,
+    matched: Tuple[str, ...] = RegexGroup(),
+):
+    type, id, flag, value = matched
+    type_ = (
+        MatchType.regex
+        if "正则" in flag
+        else MatchType.include
+        if "模糊" in flag
+        else MatchType.congruence
+    )
+    # TODO
+    pass
