@@ -1,14 +1,14 @@
 import json
+from re import M
+from typing import Dict, List, Iterator, Optional
 from pathlib import Path
-from typing import List, Optional, Dict
 
-from nonebot.adapters.onebot.v11 import Message
 from nonebot.log import logger
+from nonebot.adapters.onebot.v11 import Message, escape
 
+from .util import compare_msg
 from .models import MatchType
 from .word_entry import WordEntry
-from .util import compare_msg
-
 
 NULL_BANK = {t.name: {"0": []} for t in MatchType}
 
@@ -59,15 +59,22 @@ class WordBank(object):
         to_me: bool = False,
     ) -> List[Message]:
         """
-        匹配词条
+        :说明: `match`
+        > 匹配词条
 
-        :param index: 为0时是全局词库
-        :param msg: 需要匹配的消息
-        :param match_type: 为空表示依次尝试所有匹配方式
-                           MatchType.congruence: 全匹配(==)
-                           MatchType.include: 模糊匹配(in)
-                           MatchType.regex: 正则匹配(regex)
-        :return: 首先匹配成功的消息列表
+        :参数:
+          * `index: str`: 为0时是全局词库
+          * `msg: Message`: 需要匹配的消息
+
+        :可选参数:
+          * `match_type: Optional[MatchType] = None`: 为空表示依次尝试所有匹配方式\n
+                MatchType.congruence: 全匹配(==)
+                MatchType.include: 模糊匹配(in)
+                MatchType.regex: 正则匹配(regex)
+          * `to_me: bool = False`: 匹配 @bot
+
+        :返回:
+          - `List[Message]`: 首先匹配成功的消息列表
         """
         if match_type is None:
             for type_ in MatchType:
@@ -78,14 +85,17 @@ class WordBank(object):
         else:
             return self.__match(index, msg, match_type, to_me)
 
+    def __get_entries(self, index: str, match_type: MatchType) -> Iterator[WordEntry]:
+        for entry in self.__data[match_type.name].get(index, []):
+            yield entry
+        if index != "0":
+            for entry in self.__data[match_type.name].get("0", []):  # 加入全局词库
+                yield entry
+
     def __match(
         self, index: str, msg: Message, match_type: MatchType, to_me: bool = False
     ) -> List[Message]:
-
-        bank: List[WordEntry] = self.__data[match_type.name].get(index, [])
-        bank += self.__data[match_type.name].get("0", [])
-
-        for entry in bank:
+        for entry in self.__get_entries(index, match_type):
             if entry.match(msg, match_type, to_me):
                 return entry.get_values()
         return []
@@ -99,15 +109,23 @@ class WordBank(object):
         require_to_me: bool = False,
     ) -> bool:
         """
-        新增词条
+        :说明: `set`
+        > 新增词条
 
-        :param index: 为0时是全局词库
-        :param key: 触发短语
-        :param value: 触发后发送的短语
-        :param match_type: MatchType.congruence: 全匹配(==)
-                           MatchType.include: 模糊匹配(in)
-                           MatchType.regex: 正则匹配(regex)
-        :return:
+        :参数:
+          * `index: str`: 为0时是全局词库
+          * `match_type: MatchType`: 匹配方式\n
+                MatchType.congruence: 全匹配(==)
+                MatchType.include: 模糊匹配(in)
+                MatchType.regex: 正则匹配(regex)
+          * `key: Message`: 需要匹配的消息
+          * `value: Message`: 触发后发送的短语
+
+        :可选参数:
+          * `require_to_me: bool = False`: 匹配 @bot
+
+        :返回:
+          - `bool`: 是否新增成功
         """
         name = match_type.name
         add = False
@@ -134,14 +152,22 @@ class WordBank(object):
         require_to_me: bool = False,
     ) -> bool:
         """
-        删除词条
+        :说明: `delete`
+        > 删除词条
 
-        :param index: 为0时是全局词库
-        :param key: 触发短语
-        :param match_type: MatchType.congruence: 全匹配(==)
-                           MatchType.include: 模糊匹配(in)
-                           MatchType.regex: 正则匹配(regex)
-        :return:
+        :参数:
+          * `index: str`: 为0时是全局词库
+          * `match_type: MatchType`: 匹配方式\n
+                MatchType.congruence: 全匹配(==)
+                MatchType.include: 模糊匹配(in)
+                MatchType.regex: 正则匹配(regex)
+          * `key: Message`: 触发短语
+
+        :可选参数:
+          * `require_to_me: bool = False`: 匹配 @bot
+
+        :返回:
+          - `bool`: 是否删除成功
         """
         name = match_type.name
         for entry in list(self.__data[name].get(index, [])):
@@ -155,10 +181,14 @@ class WordBank(object):
 
     def clear(self, index: str) -> bool:
         """
-        清空某个对象的词库
+        :说明: `clear`
+        > 清空词库
 
-        :param index: 为0时是全局词库, 为空时清空所有词库
-        :return:
+        :参数:
+          * `index: str`: 为0时是全局词库, 为空时清空所有词库
+
+        :返回:
+          - `bool`: 是否清空成功
         """
         if index is None:
             self.__data = NULL_BANK
@@ -170,5 +200,26 @@ class WordBank(object):
         self.__save()
         return True
 
+    def keys(self, index: str, match_type: MatchType) -> List[Message]:
+        """
+        :说明: `keys`
+        > 获取词库的触发短语列表
+
+        :参数:
+          * `index: str`: 为0时是全局词库
+          * `match_type: MatchType`: 匹配方式\n
+                MatchType.congruence: 全匹配(==)
+                MatchType.include: 模糊匹配(in)
+                MatchType.regex: 正则匹配(regex)
+
+        :返回:
+          - `List[Message]`: 触发短语列表
+        """
+        name = match_type.name
+        keys: List[Message] = []
+        for entry in self.__data[name][index]:
+            keys.append(entry.get_key())
+        return keys
+
 
 word_bank = WordBank()
